package
Version:
v0.0.0-...-3b15a80
Opens a new window with list of versions in this module.
Published: Nov 14, 2024
License: MIT
Opens a new window with license information.
Imports: 1
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type CreateQuestionRequest struct {
Question string `json:"question"`
TestCases []TestCase `json:"testCases"`
Score int `json:"score"`
}
type FetchQuestionRequest struct {
QuestionID uint `json:"questionID"`
}
type Question struct {
gorm.Model
Question string `json:"question"`
TestCases []TestCase `json:"testCases" gorm:"foreignKey:QuestionID"`
}
type RunRequest struct {
Language string `json:"language"`
Code string `json:"code"`
Input string `json:"input"`
}
type SignInRequest struct {
Username string `json:"username"`
Password string `json:"password"`
}
type SignUpRequest struct {
Username string `json:"username"`
Password string `json:"password"`
}
type TestCase struct {
gorm.Model
QuestionID uint `json:"-"`
Input string `json:"input"`
ExpectedOutput string `json:"expectedOutput"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.